==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/fi-FI/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Salli kirjautuminen',
    'activated_disabled_help_text' => 'Et voi muokata oman tilisi aktivoinnin tilaa.',
    'assets_user'       => 'Käyttäjälle :name luovutetut laitteet',
    'bulk_update_warn'	=> 'Aiot muuttaa :user_count käyttäjän ominaisuuksia. Huomaa, että omia käyttäjätunnuksia ei voi muuttaa tämän lomakkeen avulla, vaan sinun on tehtävä muokkauksia omalle tunnuksellesi erikseen.',
    'bulk_update_help'	=> 'Tällä lomakkeella voit päivittää useita käyttäjiä kerralla. Täytä vain kentät joita haluat muuttaa. Kaikki tyhjäksi jätetyt kentät pysyvät muuttumattomina.',
    'current_assets'    => 'Käyttäjälle luovutetut laitteet',
    'clone'             => 'Monista käyttäjä',
    'contact_user'      => 'Ota yhteyttä käyttäjään :name',
    'edit'              => 'Muokkaa käyttäjää',
    'filetype_info'     => 'Sallitut tiedostotyypit ovat png, gif, jpg, jpeg, doc, docx, pdf, txt, zip ja rar.',
    'history_user'      => 'Historia käyttäjälle :name',
    'info'				=> 'Tiedot',
    'restore_user'		=> 'Klikkaa tästä palauttaaksesi ne.',
    'last_login'        => 'Viimeisin kirjautuminen',
    'ldap_config_text'  => 'LDAP-asetukset löytyvät kohdasta Järjestelmänvalvoja> Asetukset. Valittu (valinnainen) sijainti määritetään kaikille tuodulle käyttäjälle.',
    'print_assigned'    => 'Tulosta kaikki luovutetut',
    'email_assigned'    => 'Kaikkien määritettyjen sähköpostien luettelo',
    'user_notified'     => 'Käyttäjä on lähetetty sähköpostilla luettelo heidän tällä hetkellä määritetyistä kohteista.',
    'auto_assign_label' => 'Sisällytä tämä käyttäjä automaattisesti määritettäessä hyväksyttäviä lisenssejä',
    'auto_assign_help'  => 'Ohita tämä käyttäjä automaattiseen lisenssien osoittamiseen',
    'software_user'     => 'Käyttäjälle :name luovutetut ohjelmistot',
    'send_email_help'   => 'Käyttäjälle on määritettävä sähköpostiosoite lähettääksesi salasanan sähköpostitse. Salasanat voi lähettää sähköpostilla vain käyttäjän luonnin yhteydessä. Salasanat tallennetaan järjestelmään yksisuuntaisesti tiivistettyinä, eikä niitä voida lukea selväkielisenä tallennuksen jälkeen.',
    'view_user'         => 'Näytä käyttäjä :name',
    'usercsv'           => 'CSV-tiedosto',
    'two_factor_admin_optin_help' => 'Nykyiset järjestelmänvalvojan asetukset mahdollistavat kaksivaiheisen tunnistautumisen käyttöönoton valituille käyttäjille.  ',
    'two_factor_enrolled' => 'MFA-laite ilmoittautunut mukaan ',
    'two_factor_active'   => 'MFA aktiivinen',
    'user_deactivated'  => 'Käyttäjä ei voi kirjautua',
    'user_activated'  => 'Käyttäjä voi kirjautua',
    'activation_status_warning' => 'Älä muuta aktivoinnin tilaa',
    'group_memberships_helpblock' => 'Vain superadminit voivat muokata ryhmän jäsenyyksiä.',
    'superadmin_permission_warning' => 'Vain superylläpitäjät voivat myöntää käyttäjän superadmin käyttöoikeuden.',
    'admin_permission_warning' => 'Vain käyttäjät, joilla on ylläpitäjän oikeudet tai enemmän, voivat myöntää käyttäjän järjestelmänvalvojan käyttöoikeuden.',
    'remove_group_memberships' => 'Poista Ryhmäjäsenyydet',
    'warning_deletion_information' => 'Olet tarkistamassa KAIKKI kohteita :count käyttäjiltä (käyttäjistä) jotka on lueteltu alla. Super admin names on korostettu punaisella.',
    'update_user_assets_status' => 'Päivitä kaikki nimikkeet näille käyttäjille tähän tilaan',
    'checkin_user_properties' => 'Tarkista kaikki ominaisuudet, jotka liittyvät näihin käyttäjiin',
    'remote_label'   => 'Tämä on etäkäyttäjä',
    'remote'   => 'Etä',
    'remote_help' => 'Tämä voi olla hyödyllistä, jos haluat suodattaa etäkäyttäjiä, jotka eivät koskaan tai harvoin pääse fyysisiin sijainteihin.',
    'not_remote_label' => 'Tämä ei ole etäkäyttäjä',
    'vip_label' => 'VIP käyttäjä',
    'vip_help' => 'Tämä voi olla hyödyllistä merkitä tärkeitä ihmisiä omalla org jos haluat käsitellä niitä erityisellä tavalla.',
    'create_user' => 'Luo käyttäjä',
    'create_user_page_explanation' => 'Tämä on tilin tiedot, joita käytät päästäksesi sivustolle ensimmäistä kertaa.',
    'email_credentials' => 'Sähköpostin tunnistetiedot',
    'email_credentials_text' => 'Lähetä käyttäjätunnukseni sähköpostitse yllä olevaan sähköpostiosoitteeseen',
    'next_save_user' => 'Seuraava: Tallenna Käyttäjä',
    'all_assigned_list_generation' => 'Luotu:',
    'email_user_creds_on_create' => 'Lähetä tälle käyttäjälle käyttäjätunnukset?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/fi-FI/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Salli kirjautuminen',
    'activated_disabled_help_text' => 'Et voi muokata oman tilisi aktivoinnin tilaa.',
    'assets_user'       => 'Käyttäjälle :name luovutetut laitteet',
    'bulk_update_warn'	=> 'Aiot muuttaa :user_count käyttäjän ominaisuuksia. Huomaa, että omia käyttäjätunnuksia ei voi muuttaa tämän lomakkeen avulla, vaan sinun on tehtävä muokkauksia omalle tunnuksellesi erikseen.',
    'bulk_update_help'	=> 'Tällä lomakkeella voit päivittää useita käyttäjiä kerralla. Täytä vain kentät joita haluat muuttaa. Kaikki tyhjäksi jätetyt kentät pysyvät muuttumattomina.',
    'current_assets'    => 'Käyttäjälle luovutetut laitteet',
    'clone'             => 'Monista käyttäjä',
    'contact_user'      => 'Ota yhteyttä käyttäjään :name',
    'edit'              => 'Muokkaa käyttäjää',
    'filetype_info'     => 'Sallitut tiedostotyypit ovat png, gif, jpg, jpeg, doc, docx, pdf, txt, zip ja rar.',
    'history_user'      => 'Historia käyttäjälle :name',
    'info'				=> 'Tiedot',
    'restore_user'		=> 'Klikkaa tästä palauttaaksesi ne.',
    'last_login'        => 'Viimeisin kirjautuminen',
    'ldap_config_text'  => 'LDAP-asetukset löytyvät kohdasta Järjestelmänvalvoja> Asetukset. Valittu (valinnainen) sijainti määritetään kaikille tuodulle käyttäjälle.',
    'print_assigned'    => 'Tulosta kaikki luovutetut',
    'email_assigned'    => 'Kaikkien määritettyjen sähköpostien luettelo',
    'user_notified'     => 'Käyttäjä on lähetetty sähköpostilla luettelo heidän tällä hetkellä määritetyistä kohteista.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Sisällytä tämä käyttäjä automaattisesti määritettäessä hyväksyttäviä lisenssejä',
    'auto_assign_help'  => 'Ohita tämä käyttäjä automaattiseen lisenssien osoittamiseen',
    'software_user'     => 'Käyttäjälle :name luovutetut ohjelmistot',
    'send_email_help'   => 'Käyttäjälle on määritettävä sähköpostiosoite lähettääksesi salasanan sähköpostitse. Salasanat voi lähettää sähköpostilla vain käyttäjän luonnin yhteydessä. Salasanat tallennetaan järjestelmään yksisuuntaisesti tiivistettyinä, eikä niitä voida lukea selväkielisenä tallennuksen jälkeen.',
    'view_user'         => 'Näytä käyttäjä :name',
    'usercsv'           => 'CSV-tiedosto',
    'two_factor_admin_optin_help' => 'Nykyiset järjestelmänvalvojan asetukset mahdollistavat kaksivaiheisen tunnistautumisen käyttöönoton valituille käyttäjille.  ',
    'two_factor_enrolled' => 'MFA-laite ilmoittautunut mukaan ',
    'two_factor_active'   => 'MFA aktiivinen',
    'user_deactivated'  => 'Käyttäjä ei voi kirjautua',
    'user_activated'  => 'Käyttäjä voi kirjautua',
    'activation_status_warning' => 'Älä muuta aktivoinnin tilaa',
    'group_memberships_helpblock' => 'Vain superadminit voivat muokata ryhmän jäsenyyksiä.',
    'superadmin_permission_warning' => 'Vain superylläpitäjät voivat myöntää käyttäjän superadmin käyttöoikeuden.',
    'admin_permission_warning' => 'Vain käyttäjät, joilla on ylläpitäjän oikeudet tai enemmän, voivat myöntää käyttäjän järjestelmänvalvojan käyttöoikeuden.',
    'remove_group_memberships' => 'Poista Ryhmäjäsenyydet',
    'warning_deletion_information' => 'Olet tarkistamassa KAIKKI kohteita :count käyttäjiltä (käyttäjistä) jotka on lueteltu alla. Super admin names on korostettu punaisella.',
    'update_user_assets_status' => 'Päivitä kaikki nimikkeet näille käyttäjille tähän tilaan',
    'checkin_user_properties' => 'Tarkista kaikki ominaisuudet, jotka liittyvät näihin käyttäjiin',
    'remote_label'   => 'Tämä on etäkäyttäjä',
    'remote'   => 'Etä',
    'remote_help' => 'Tämä voi olla hyödyllistä, jos haluat suodattaa etäkäyttäjiä, jotka eivät koskaan tai harvoin pääse fyysisiin sijainteihin.',
    'not_remote_label' => 'Tämä ei ole etäkäyttäjä',
    'vip_label' => 'VIP käyttäjä',
    'vip_help' => 'Tämä voi olla hyödyllistä merkitä tärkeitä ihmisiä omalla org jos haluat käsitellä niitä erityisellä tavalla.',
    'create_user' => 'Luo käyttäjä',
    'create_user_page_explanation' => 'Tämä on tilin tiedot, joita käytät päästäksesi sivustolle ensimmäistä kertaa.',
    'email_credentials' => 'Sähköpostin tunnistetiedot',
    'email_credentials_text' => 'Lähetä käyttäjätunnukseni sähköpostitse yllä olevaan sähköpostiosoitteeseen',
    'next_save_user' => 'Seuraava: Tallenna Käyttäjä',
    'all_assigned_list_generation' => 'Luotu:',
    'email_user_creds_on_create' => 'Lähetä tälle käyttäjälle käyttäjätunnukset?',
];
